==> interweave-0.0.2.tgz: package/tests/Interweave.test.js <==
import React from 'react';
import { expect } from 'chai';
import { shallow } from 'enzyme';
import Interweave from '../lib/Interweave';
import { Element, Email, Emoji, Hashtag, Url } from '../lib/components';
import { EmailMatcher, EmojiMatcher, HashtagMatcher, IpMatcher, UrlMatcher } from '../lib/matchers';
import { MockFilter, MockMatcher, HrefFilter, CodeTagMatcher } from './mocks';

describe('Interweave', () => {
  const urlParts = {
    scheme: 'http',
    auth: '',
    host: '',
    port: '',
    path: '',
    query: '',
    fragment: '',
  };

  beforeEach(() => {
    Interweave.clearFilters();
    Interweave.clearMatchers();
  });

  it('can pass filters through props', () => {
    const wrapper = shallow(
      <Interweave
        filters={[new HrefFilter()]}
        markup={`Foo <a href="foo.com">Bar</a> Baz`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="a" key="0" attributes={{ href: 'bar.net' }}>{['Bar']}</Element>,
      ' Baz',
    ]);
  });

  it('can disable all filters using `noFilters`', () => {
    const wrapper = shallow(
      <Interweave
        filters={[new HrefFilter()]}
        noFilters
        markup={'Foo <a href="foo.com">Bar</a> Baz'}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="a" key="0" attributes={{ href: 'foo.com' }}>{['Bar']}</Element>,
      ' Baz',
    ]);
  });

  it('can pass matchers through props', () => {
    const wrapper = shallow(
      <Interweave
        matchers={[new CodeTagMatcher('b', '1')]}
        markup="Foo [b] Bar Baz"
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="span" key="1" customProp="foo">B</Element>,
      ' Bar Baz',
    ]);
  });

  it('can disable all matchers using `noMatchers', () => {
    const wrapper = shallow(
      <Interweave
        matchers={[new CodeTagMatcher('b', '1')]}
        noMatchers
        markup="Foo [b] Bar Baz"
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo [b] Bar Baz',
    ]);
  });

  describe('addFilter()', () => {
    it('errors if not a filter', () => {
      expect(() => {
        Interweave.addFilter('notafilter');
      }).to.throw(TypeError, 'Filter must be an instance of the `Filter` class.');
    });

    it('errors if not a supported attribute', () => {
      expect(() => {
        Interweave.addFilter(new MockFilter('onclick'));
      }).to.throw(Error, 'Attribute "onclick" is not supported.');
    });

    it('adds a filter with a priority', () => {
      Interweave.addFilter(new MockFilter('href'), 5);

      expect(Interweave.getFilters()).to.deep.equal([
        { filter: new MockFilter('href'), priority: 5 },
      ]);
    });

    it('adds a filter with an incrementing priority and sorts', () => {
      Interweave.addFilter(new MockFilter('href'));
      Interweave.addFilter(new MockFilter('href'), 10);
      Interweave.addFilter(new MockFilter('href'));

      expect(Interweave.getFilters()).to.deep.equal([
        { filter: new MockFilter('href'), priority: 10 },
        { filter: new MockFilter('href'), priority: 100 },
        { filter: new MockFilter('href'), priority: 102 },
      ]);
    });
  });

  describe('addMatcher()', () => {
    it('errors if not a matcher', () => {
      expect(() => {
        Interweave.addMatcher('notamatcher');
      }).to.throw(TypeError, 'Matcher must be an instance of the `Matcher` class.');
    });

    it('errors if using the html name', () => {
      expect(() => {
        Interweave.addMatcher(new MockMatcher('html'));
      }).to.throw(Error, 'The matcher name "html" is not allowed.');
    });

    it('adds a matcher with an incrementing priority and sorts', () => {
      Interweave.addMatcher(new MockMatcher('emoji'));
      Interweave.addMatcher(new MockMatcher('email'), 10);
      Interweave.addMatcher(new MockMatcher('url'));

      expect(Interweave.getMatchers()).to.deep.equal([
        { matcher: new MockMatcher('email'), priority: 10 },
        { matcher: new MockMatcher('emoji'), priority: 100 },
        { matcher: new MockMatcher('url'), priority: 102 },
      ]);
    });

    it('sets an inverse named prop types', () => {
      expect(Interweave.propTypes.noBazQux).to.be.an('undefined');

      Interweave.addMatcher(new MockMatcher('bazQux'));

      expect(Interweave.propTypes.noBazQux).to.be.a('function');
    });
  });

  describe('parseMarkup()', () => {
    it('errors if onBeforeParse doesnt return a string', () => {
      expect(() => {
        shallow(<Interweave onBeforeParse={() => 123} markup="Foo" />);
      }).to.throw(TypeError, 'Interweave `onBeforeParse` must return a valid HTML string.');
    });

    it('errors if onAfterParse doesnt return an array', () => {
      expect(() => {
        shallow(<Interweave onAfterParse={() => 123} markup="Foo" />);
      }).to.throw(TypeError, 'Interweave `onAfterParse` must return an array of strings and React elements.');
    });

    it('can modify the markup using onBeforeParse', () => {
      const wrapper = shallow(
        <Interweave
          onBeforeParse={content => content.replace(/b>/g, 'i>')}
          markup={'Foo <b>Bar</b> Baz'}
        />
      ).shallow();

      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="i" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
      ]);
    });

    it('can modify the tree using onAfterParse', () => {
      const wrapper = shallow(
        <Interweave
          onAfterParse={(content) => {
            content.push(<Element tagName="u" key="1">Qux</Element>);
            return content;
          }}
          markup={'Foo <b>Bar</b> Baz'}
        />
      ).shallow();

      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="b" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
        <Element tagName="u" key="1">Qux</Element>,
      ]);
    });
  });

  describe('render()', () => {
    it('renders with a default tag name', () => {
      const wrapper = shallow(<Interweave markup="Foo" />).shallow();

      expect(wrapper.find('span')).to.have.lengthOf(1);
      expect(wrapper.text()).to.equal('Foo');
    });

    it('renders with a custom tag name', () => {
      const wrapper = shallow(<Interweave tagName="div" markup="Foo" />).shallow();

      expect(wrapper.find('div')).to.have.lengthOf(1);
      expect(wrapper.text()).to.equal('Foo');
    });

    it('parses HTML', () => {
      const wrapper = shallow(<Interweave tagName="div" markup={'Foo <b>Bar</b> Baz'} />).shallow();

      expect(wrapper.find('div')).to.have.lengthOf(1);
      expect(wrapper.find('Element').prop('tagName')).to.equal('b');
      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="b" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
      ]);
    });
  });

  it('parses and renders large blocks of text with all matchers', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec massa lorem, mollis non commodo quis, ultricies at elit. email@domain.com. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. #interweave Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper :japanese_castle: id vestibulum id, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, www.domain.com.

Curabitur lectus odio, tempus quis velit vitae, cursus sagittis nulla. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. https://127.0.0.1/foo Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (http://domain.com/some/path?with=query). Pellentesque ac finibus mauris. Sed eu luctus diam. Quisque porta lectus in turpis imperdiet dapibus.

#blessed #interweave #milesj`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec massa lorem, mollis non commodo quis, ultricies at elit. ',
      <Email key="0" emailParts={{ username: 'email', host: 'domain.com' }}>email@domain.com</Email>,
      '. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. ',
      <Hashtag key="2" hashtagName="interweave">#interweave</Hashtag>,
      ' Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper ',
      <Emoji key="1" shortName=":japanese_castle:" />,
      ' id vestibulum id, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, ',
      <Url key="7" urlParts={{ ...urlParts, host: 'www.domain.com' }}>www.domain.com</Url>,
      '.\n\nCurabitur lectus odio, tempus quis velit vitae, cursus sagittis nulla. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. ',
      <Url key="6" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
      ' Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (',
      <Url key="8" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
      '). Pellentesque ac finibus mauris. Sed eu luctus diam. Quisque porta lectus in turpis imperdiet dapibus.\n\n',
      <Hashtag key="3" hashtagName="blessed">#blessed</Hashtag>,
      ' ',
      <Hashtag key="4" hashtagName="interweave">#interweave</Hashtag>,
      ' ',
      <Hashtag key="5" hashtagName="milesj">#milesj</Hashtag>,
    ]);
  });

  it('parses and renders HTML text with all matchers', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`<h1>Lorem ipsum dolor sit amet</h1>

<p><b>Consectetur adipiscing elit.</b> Donec massa lorem, mollis non commodo quis, ultricies at elit. email@domain.com. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. #interweave Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper id vestibulum id :love_letter:, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, <a href="www.domain.com">www.domain.com</a>.</p>

<br />:ok_woman_tone3:<br />

<div>Curabitur lectus odio, <em>tempus quis velit vitae, cursus sagittis nulla</em>. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. https://127.0.0.1/foo Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (http://domain.com/some/path?with=query). Pellentesque ac finibus mauris. Sed eu luctus diam. :not_an_emoji: Quisque porta lectus in turpis imperdiet dapibus.</div>

<section>#blessed #interweave #milesj</section>`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      <Element key="0" tagName="h1" attributes={{}}>{['Lorem ipsum dolor sit amet']}</Element>,
      '\n\n',
      <Element key="1" tagName="p" attributes={{}}>
        {[
          <Element key="2" tagName="b" attributes={{}}>{['Consectetur adipiscing elit.']}</Element>,
          ' Donec massa lorem, mollis non commodo quis, ultricies at elit. ',
          <Email key="3" emailParts={{ username: 'email', host: 'domain.com' }}>email@domain.com</Email>,
          '. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. ',
          <Hashtag key="5" hashtagName="interweave">#interweave</Hashtag>,
          ' Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper id vestibulum id ',
          <Emoji key="4" shortName=":love_letter:" />,
          ', viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, ',
          <Element key="6" tagName="a" attributes={{ href: 'www.domain.com' }}>{['www.domain.com']}</Element>,
          '.',
        ]}
      </Element>,
      '\n\n',
      <Element key="7" tagName="br" attributes={{}}>{[]}</Element>,
      <Emoji key="8" shortName=":ok_woman_tone3:" />,
      <Element key="9" tagName="br" attributes={{}}>{[]}</Element>,
      '\n\n',
      <Element key="10" tagName="div" attributes={{}}>
        {[
          'Curabitur lectus odio, ',
          <Element key="11" tagName="em" attributes={{}}>{['tempus quis velit vitae, cursus sagittis nulla']}</Element>,
          '. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. ',
          <Url key="12" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
          ' Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (',
          <Url key="13" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
          '). Pellentesque ac finibus mauris. Sed eu luctus diam. :not_an_emoji: Quisque porta lectus in turpis imperdiet dapibus.',
        ]}
      </Element>,
      '\n\n',
      <Element key="14" tagName="section" attributes={{}}>
        {[
          <Hashtag key="15" hashtagName="blessed">#blessed</Hashtag>,
          ' ',
          <Hashtag key="16" hashtagName="interweave">#interweave</Hashtag>,
          ' ',
          <Hashtag key="17" hashtagName="milesj">#milesj</Hashtag>,
        ]}
      </Element>,
    ]);
  });

  it('parses and doesnt render anchor links within anchor links', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`- https://127.0.0.1/foo
- <a href="www.domain.com">www.domain.com</a>
- (http://domain.com/some/path?with=query)
- <a href="http://domain.com">This text should stay</a>`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      '- ',
      <Url key="0" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
      '\n- ',
      <Element key="1" tagName="a" attributes={{ href: 'www.domain.com' }}>{['www.domain.com']}</Element>,
      '\n- (',
      <Url key="2" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
      ')\n- ',
      <Element key="3" tagName="a" attributes={{ href: 'http://domain.com' }}>{['This text should stay']}</Element>,
    ]);
  });
});

==> interweave-0.1.0.tgz: package/tests/Interweave.test.js <==
import React from 'react';
import { expect } from 'chai';
import { shallow } from 'enzyme';
import Interweave from '../lib/Interweave';
import { Element, Email, Emoji, Hashtag, Url } from '../lib/components';
import { EmailMatcher, EmojiMatcher, HashtagMatcher, IpMatcher, UrlMatcher } from '../lib/matchers';
import { MockFilter, MockMatcher, HrefFilter, CodeTagMatcher } from './mocks';

describe('Interweave', () => {
  const urlParts = {
    scheme: 'http',
    auth: '',
    host: '',
    port: '',
    path: '',
    query: '',
    fragment: '',
  };

  beforeEach(() => {
    Interweave.clearFilters();
    Interweave.clearMatchers();
  });

  it('can pass filters through props', () => {
    const wrapper = shallow(
      <Interweave
        filters={[new HrefFilter()]}
        markup={'Foo <a href="foo.com">Bar</a> Baz'}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="a" key="0" attributes={{ href: 'bar.net' }}>{['Bar']}</Element>,
      ' Baz',
    ]);
  });

  it('can disable all filters using `disableFilters`', () => {
    const wrapper = shallow(
      <Interweave
        filters={[new HrefFilter()]}
        disableFilters
        markup={'Foo <a href="foo.com">Bar</a> Baz'}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="a" key="0" attributes={{ href: 'foo.com' }}>{['Bar']}</Element>,
      ' Baz',
    ]);
  });

  it('can pass matchers through props', () => {
    const wrapper = shallow(
      <Interweave
        matchers={[new CodeTagMatcher('b', '1')]}
        markup="Foo [b] Bar Baz"
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo ',
      <Element tagName="span" key="1" customProp="foo">B</Element>,
      ' Bar Baz',
    ]);
  });

  it('can disable all matchers using `disableMatchers', () => {
    const wrapper = shallow(
      <Interweave
        matchers={[new CodeTagMatcher('b', '1')]}
        disableMatchers
        markup="Foo [b] Bar Baz"
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Foo [b] Bar Baz',
    ]);
  });

  describe('addFilter()', () => {
    it('errors if not a filter', () => {
      expect(() => {
        Interweave.addFilter('notafilter');
      }).to.throw(TypeError, 'Filter must be an instance of the `Filter` class.');
    });

    it('errors if not a supported attribute', () => {
      expect(() => {
        Interweave.addFilter(new MockFilter('onclick'));
      }).to.throw(Error, 'Attribute "onclick" is not supported.');
    });

    it('adds a filter with a priority', () => {
      Interweave.addFilter(new MockFilter('href'), 5);

      expect(Interweave.getFilters()).to.deep.equal([
        { filter: new MockFilter('href'), priority: 5 },
      ]);
    });

    it('adds a filter with an incrementing priority and sorts', () => {
      Interweave.addFilter(new MockFilter('href'));
      Interweave.addFilter(new MockFilter('href'), 10);
      Interweave.addFilter(new MockFilter('href'));

      expect(Interweave.getFilters()).to.deep.equal([
        { filter: new MockFilter('href'), priority: 10 },
        { filter: new MockFilter('href'), priority: 100 },
        { filter: new MockFilter('href'), priority: 102 },
      ]);
    });
  });

  describe('addMatcher()', () => {
    it('errors if not a matcher', () => {
      expect(() => {
        Interweave.addMatcher('notamatcher');
      }).to.throw(TypeError, 'Matcher must be an instance of the `Matcher` class.');
    });

    it('errors if using the html name', () => {
      expect(() => {
        Interweave.addMatcher(new MockMatcher('html'));
      }).to.throw(Error, 'The matcher name "html" is not allowed.');
    });

    it('adds a matcher with an incrementing priority and sorts', () => {
      Interweave.addMatcher(new MockMatcher('emoji'));
      Interweave.addMatcher(new MockMatcher('email'), 10);
      Interweave.addMatcher(new MockMatcher('url'));

      expect(Interweave.getMatchers()).to.deep.equal([
        { matcher: new MockMatcher('email'), priority: 10 },
        { matcher: new MockMatcher('emoji'), priority: 100 },
        { matcher: new MockMatcher('url'), priority: 102 },
      ]);
    });

    it('sets an inverse named prop types', () => {
      expect(Interweave.propTypes.noBazQux).to.be.an('undefined');

      Interweave.addMatcher(new MockMatcher('bazQux'));

      expect(Interweave.propTypes.noBazQux).to.be.a('function');
    });
  });

  describe('parseMarkup()', () => {
    it('errors if onBeforeParse doesnt return a string', () => {
      expect(() => {
        shallow(<Interweave onBeforeParse={() => 123} markup="Foo" />);
      }).to.throw(TypeError, 'Interweave `onBeforeParse` must return a valid HTML string.');
    });

    it('errors if onAfterParse doesnt return an array', () => {
      expect(() => {
        shallow(<Interweave onAfterParse={() => 123} markup="Foo" />);
      }).to.throw(TypeError, 'Interweave `onAfterParse` must return an array of strings and React elements.');
    });

    it('can modify the markup using onBeforeParse', () => {
      const wrapper = shallow(
        <Interweave
          onBeforeParse={content => content.replace(/b>/g, 'i>')}
          markup={'Foo <b>Bar</b> Baz'}
        />
      ).shallow();

      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="i" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
      ]);
    });

    it('can modify the tree using onAfterParse', () => {
      const wrapper = shallow(
        <Interweave
          onAfterParse={(content) => {
            content.push(<Element tagName="u" key="1">Qux</Element>);
            return content;
          }}
          markup={'Foo <b>Bar</b> Baz'}
        />
      ).shallow();

      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="b" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
        <Element tagName="u" key="1">Qux</Element>,
      ]);
    });
  });

  describe('render()', () => {
    it('renders with a default tag name', () => {
      const wrapper = shallow(<Interweave markup="Foo" />).shallow();

      expect(wrapper.find('span')).to.have.lengthOf(1);
      expect(wrapper.text()).to.equal('Foo');
    });

    it('renders with a custom tag name', () => {
      const wrapper = shallow(<Interweave tagName="div" markup="Foo" />).shallow();

      expect(wrapper.find('div')).to.have.lengthOf(1);
      expect(wrapper.text()).to.equal('Foo');
    });

    it('parses HTML', () => {
      const wrapper = shallow(<Interweave tagName="div" markup={'Foo <b>Bar</b> Baz'} />).shallow();

      expect(wrapper.find('div')).to.have.lengthOf(1);
      expect(wrapper.find('Element').prop('tagName')).to.equal('b');
      expect(wrapper.prop('children')).to.deep.equal([
        'Foo ',
        <Element tagName="b" key="0" attributes={{}}>{['Bar']}</Element>,
        ' Baz',
      ]);
    });
  });

  it('parses and renders large blocks of text with all matchers', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec massa lorem, mollis non commodo quis, ultricies at elit. email@domain.com. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. #interweave Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper :japanese_castle: id vestibulum id, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, www.domain.com.

Curabitur lectus odio, tempus quis velit vitae, cursus sagittis nulla. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. https://127.0.0.1/foo Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (http://domain.com/some/path?with=query). Pellentesque ac finibus mauris. Sed eu luctus diam. Quisque porta lectus in turpis imperdiet dapibus.

#blessed #interweave #milesj`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec massa lorem, mollis non commodo quis, ultricies at elit. ',
      <Email key="0" emailParts={{ username: 'email', host: 'domain.com' }}>email@domain.com</Email>,
      '. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. ',
      <Hashtag key="2" hashtagName="interweave">#interweave</Hashtag>,
      ' Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper ',
      <Emoji key="1" shortName=":japanese_castle:" />,
      ' id vestibulum id, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, ',
      <Url key="7" urlParts={{ ...urlParts, host: 'www.domain.com' }}>www.domain.com</Url>,
      '.\n\nCurabitur lectus odio, tempus quis velit vitae, cursus sagittis nulla. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. ',
      <Url key="6" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
      ' Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (',
      <Url key="8" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
      '). Pellentesque ac finibus mauris. Sed eu luctus diam. Quisque porta lectus in turpis imperdiet dapibus.\n\n',
      <Hashtag key="3" hashtagName="blessed">#blessed</Hashtag>,
      ' ',
      <Hashtag key="4" hashtagName="interweave">#interweave</Hashtag>,
      ' ',
      <Hashtag key="5" hashtagName="milesj">#milesj</Hashtag>,
    ]);
  });

  it('parses and renders HTML text with all matchers', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`<h1>Lorem ipsum dolor sit amet</h1>

<p><b>Consectetur adipiscing elit.</b> Donec massa lorem, mollis non commodo quis, ultricies at elit. email@domain.com. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. #interweave Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper id vestibulum id :love_letter:, viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, <a href="www.domain.com">www.domain.com</a>.</p>

<br />:ok_woman_tone3:<br />

<div>Curabitur lectus odio, <em>tempus quis velit vitae, cursus sagittis nulla</em>. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. https://127.0.0.1/foo Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (http://domain.com/some/path?with=query). Pellentesque ac finibus mauris. Sed eu luctus diam. :not_an_emoji: Quisque porta lectus in turpis imperdiet dapibus.</div>

<section>#blessed #interweave #milesj</section>`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      <Element key="0" tagName="h1" attributes={{}}>{['Lorem ipsum dolor sit amet']}</Element>,
      '\n\n',
      <Element key="1" tagName="p" attributes={{}}>
        {[
          <Element key="2" tagName="b" attributes={{}}>{['Consectetur adipiscing elit.']}</Element>,
          ' Donec massa lorem, mollis non commodo quis, ultricies at elit. ',
          <Email key="3" emailParts={{ username: 'email', host: 'domain.com' }}>email@domain.com</Email>,
          '. Aliquam a arcu porttitor, aliquam eros sed, convallis massa. Nunc vitae vehicula quam, in feugiat ligula. ',
          <Hashtag key="5" hashtagName="interweave">#interweave</Hashtag>,
          ' Donec eu sem non nibh condimentum luctus. Vivamus pharetra feugiat blandit. Vestibulum neque velit, semper id vestibulum id ',
          <Emoji key="4" shortName=":love_letter:" />,
          ', viverra a felis. Integer convallis in orci nec bibendum. Ut consequat posuere metus, ',
          <Element key="6" tagName="a" attributes={{ href: 'www.domain.com' }}>{['www.domain.com']}</Element>,
          '.',
        ]}
      </Element>,
      '\n\n',
      <Element key="7" tagName="br" attributes={{}}>{[]}</Element>,
      <Emoji key="8" shortName=":ok_woman_tone3:" />,
      <Element key="9" tagName="br" attributes={{}}>{[]}</Element>,
      '\n\n',
      <Element key="10" tagName="div" attributes={{}}>
        {[
          'Curabitur lectus odio, ',
          <Element key="11" tagName="em" attributes={{}}>{['tempus quis velit vitae, cursus sagittis nulla']}</Element>,
          '. Maecenas sem nulla, tempor nec risus nec, ultricies ultricies magna. ',
          <Url key="12" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
          ' Nulla malesuada lacinia libero non mollis. Curabitur id lacus id dolor vestibulum ornare quis a nisi (',
          <Url key="13" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
          '). Pellentesque ac finibus mauris. Sed eu luctus diam. :not_an_emoji: Quisque porta lectus in turpis imperdiet dapibus.',
        ]}
      </Element>,
      '\n\n',
      <Element key="14" tagName="section" attributes={{}}>
        {[
          <Hashtag key="15" hashtagName="blessed">#blessed</Hashtag>,
          ' ',
          <Hashtag key="16" hashtagName="interweave">#interweave</Hashtag>,
          ' ',
          <Hashtag key="17" hashtagName="milesj">#milesj</Hashtag>,
        ]}
      </Element>,
    ]);
  });

  it('parses and doesnt render anchor links within anchor links', () => {
    const wrapper = shallow(
      <Interweave
        tagName="div"
        matchers={[
          new EmailMatcher('email'),
          new EmojiMatcher('emoji'),
          new HashtagMatcher('hashtag'),
          new IpMatcher('ip'),
          new UrlMatcher('url'),
        ]}
        markup={`- https://127.0.0.1/foo
- <a href="www.domain.com">www.domain.com</a>
- (http://domain.com/some/path?with=query)
- <a href="http://domain.com">This text should stay</a>`}
      />
    ).shallow();

    expect(wrapper.prop('children')).to.deep.equal([
      '- ',
      <Url key="0" urlParts={{ ...urlParts, scheme: 'https', host: '127.0.0.1', path: '/foo' }}>https://127.0.0.1/foo</Url>,
      '\n- ',
      <Element key="1" tagName="a" attributes={{ href: 'www.domain.com' }}>{['www.domain.com']}</Element>,
      '\n- (',
      <Url key="2" urlParts={{ ...urlParts, host: 'domain.com', path: '/some/path', query: '?with=query' }}>http://domain.com/some/path?with=query</Url>,
      ')\n- ',
      <Element key="3" tagName="a" attributes={{ href: 'http://domain.com' }}>{['This text should stay']}</Element>,
    ]);
  });
});
